# Content used by GitHub workflows

[Markdown]: https://docs.github.com/en/get-started/writing-on-github/getting-started-with-writing-and-formatting-on-github/about-writing-and-formatting-on-github

The [`.github/content`](.) directory contains [Markdown] files that get
posted as comments, issues, or pull request descriptions by various
workflows in [`.github/workflows`](../workflows).
